@@ -29,10 +29,6 @@ class TestCrossover(unittest.TestCase):
         self.features['precision'] = 7
         self.features['feasible'] = 0.0
 
-    def test_pokus(self):
-        from .. import __version__
-        print(__version__)
-
     def test_simple_mutation(self):
         sm = SimpleMutator(self.parameters, 0.7)
         individual = sm.mutate(self.i1)
